@@ -11,6 +11,7 @@ fn it_extracts_const_entry_correctly() {
     match entries[0] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"alloc::boxed::HEAP".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"HEAP");
             assert_eq!(e.entry_type, *"Constant".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -29,6 +30,7 @@ fn it_extracts_enum_entry_correctly() {
     match entries[0] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"collections::borrow::Cow".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"Cow");
             assert_eq!(e.entry_type, *"Enum".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -47,6 +49,7 @@ fn it_extracts_function_entry_correctly() {
     match entries[0] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"std::fs::metadata".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"metadata");
             assert_eq!(e.entry_type, *"Function".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -65,6 +68,7 @@ fn it_extracts_macro_entry_correctly() {
     match entries[0] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"std::println!".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"println!");
             assert_eq!(e.entry_type, *"Macro".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -83,6 +87,7 @@ fn it_extracts_trait_method_entry_correctly() {
         Some(ref e) => {
             assert_eq!(e.entry_name,
                        *"collections::borrow::Borrow::borrow".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"borrow");
             assert_eq!(e.entry_type, *"Method".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -101,6 +106,7 @@ fn it_extracts_enum_method_entry_correctly() {
         Some(ref e) => {
             assert_eq!(e.entry_name,
                        *"collections::borrow::Cow::to_mut".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"to_mut");
             assert_eq!(e.entry_type, *"Method".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -119,6 +125,7 @@ fn it_extracts_struct_method_entry_correctly() {
     match entries[3] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"core::any::TypeId::of".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"of");
             assert_eq!(e.entry_type, *"Method".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -136,6 +143,7 @@ fn it_extracts_module_entry_correctly() {
     match entries[0] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"collections".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"collections");
             assert_eq!(e.entry_type, *"Module".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -154,6 +162,7 @@ fn it_extracts_struct_entry_correctly() {
     match entries[0] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"std::io::Bytes".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"Bytes");
             assert_eq!(e.entry_type, *"Struct".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -171,6 +180,7 @@ fn it_extracts_trait_entry_correctly() {
     match entries[0] {
         Some(ref e) => {
             assert_eq!(e.entry_name, *"collections::fmt::Binary".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"Binary");
             assert_eq!(e.entry_type, *"Trait".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -184,10 +194,10 @@ fn it_extracts_type_entry_correctly() {
     let mut entries: Vec<Option<super::Entry>> = Vec::new();
     parser::walk_tree(&dom.document, String::from(""), &mut entries);
 
-    assert_eq!(entries.len(), 1);
-    match entries[0] {
+    match entries[1] {
         Some(ref e) => {
-            assert_eq!(e.entry_name, *"bool::Output".to_string());
+            assert_eq!(e.entry_name, *"core::iter::Chain::Item".to_string());
+            assert_eq!(*e.anchor_name.split("/").nth(4).unwrap(), *"Item");
             assert_eq!(e.entry_type, *"Type".to_string());
             assert_eq!(e.is_section, false);
         }
@@ -206,7 +216,39 @@ fn it_extracts_impl_entry_correctly() {
         Some(ref e) => {
             assert_eq!(e.entry_type, *"Method".to_string());
             assert_eq!(e.is_section, true);
-            assert_eq!(e.entry_name, *"impl<T: Clone> Arc<T>".to_string());
+        }
+        _ => assert!(false),
+    }
+}
+
+#[test]
+fn it_extracts_field_entry_correctly() {
+    let dom = fixtures::dom_from_snippet(fixtures::FIELD_SNIPPET);
+    let mut entries: Vec<Option<super::Entry>> = Vec::new();
+    parser::walk_tree(&dom.document, String::from(""), &mut entries);
+
+    match entries[1] {
+        Some(ref e) => {
+            assert_eq!(e.entry_type, *"Field".to_string());
+            assert_eq!(e.is_section, false);
+            assert_eq!(e.entry_name, *"core::ops::Range::start".to_string());
+        }
+        _ => assert!(false),
+    }
+}
+
+#[test]
+fn it_extracts_variants_entry_correctly() {
+    let dom = fixtures::dom_from_snippet(fixtures::VARIANT_SNIPPET);
+    let mut entries: Vec<Option<super::Entry>> = Vec::new();
+    parser::walk_tree(&dom.document, String::from(""), &mut entries);
+
+    match entries[1] {
+        Some(ref e) => {
+            assert_eq!(e.entry_type, *"Variant".to_string());
+            assert_eq!(e.is_section, false);
+            assert_eq!(e.entry_name,
+                       *"collections::borrow::Cow::Borrowed".to_string());
         }
         _ => assert!(false),
     }
